function [p, pi, pc, pic, px, pix, y, c, x] = dual_stickiness_Mobility(paramvec, impT)

nvar = 15;   % number of variables
nz   = 2;    % number of exogenous variables (m_{t-1}, m_{t})

%Variable names
ENDOGENOUS_VARIABLE_NAMES={'p'
'pc'
'px'
'qc'
'qx'
'pcst'
'pxst'
'mcc'
'mcx'
'y'
'c'
'x'
'd'
'kc'
'kx'};
EXOGENOUS_VARIABLE_NAMES={'Money Supply1'};

ip    = 1;
ipc   = 2;
ipx   = 3;
iqc   = 4;
iqx   = 5;
ipcst = 6;
ipxst = 7;
imcc  = 8;
imcx  = 9;
iy    = 10;
ic    = 11;
ix    = 12;
id    = 13;
ikc   = 14;
ikx   = 15;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Calculate other parameter values %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
rhoM = 0.53; % AR(1) coefficient of money growth

A_0=zeros(nvar,nvar);
B_0=zeros(nvar,nvar);
C_0=zeros(nvar,nvar);
F_0=zeros(nvar,nz);
G_0=zeros(nvar,nz);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Initialize vectors to store impulse responses %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
p   = zeros(impT,size(paramvec,1));
pi  = zeros(impT,size(paramvec,1));
pc  = zeros(impT,size(paramvec,1));
pic = zeros(impT,size(paramvec,1));
px  = zeros(impT,size(paramvec,1));
pix = zeros(impT,size(paramvec,1));
y   = zeros(impT,size(paramvec,1));
c   = zeros(impT,size(paramvec,1));
x   = zeros(impT,size(paramvec,1));
wc  = zeros(impT,size(paramvec,1));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% For loop for the number of combinations of parameter values %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for idx=1:size(paramvec,1)

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Set parameter values %%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%
    kappaC = paramvec(idx,1);
    phiC   = paramvec(idx,2);
    phiX   = paramvec(idx,3);
    thetaC = paramvec(idx,4);
    thetaX = paramvec(idx,5);
    sigmai = 1/paramvec(idx,6);
    rhoi   = 1/paramvec(idx,7);
    delta  = paramvec(idx,8);
    eta    = paramvec(idx,9);
    alpha  = paramvec(idx, 10);
    beta   = paramvec(idx, 11);
    epsilon = paramvec(idx, 12);
    xi     = paramvec(idx, 13);
    kappaX = 1-kappaC;
    
    CHI     = (1.0-beta*(1.0-delta))/delta * (1.0-kappaC)/kappaC;
    ucc     = (rhoi - sigmai)/(1.0 + CHI) - rhoi;
    ucd     = (rhoi - sigmai)/(1.0 + 1.0/CHI);
    udc     = (rhoi - sigmai)/(1.0 + CHI);
    udd     = (rhoi - sigmai)/(1.0 + 1.0/CHI) - rhoi;
    
    omegap = alpha/(1.0-alpha);                             
    Nc2Nx  = (kappaC/(1.0-kappaC))^(eta/(1.0+eta));
    omegaC = (1.0/eta+1.0-xi)*Nc2Nx^(xi)/(1.0+Nc2Nx^(xi));
    omegaX = (1.0/eta+1.0-xi)/(1.0+Nc2Nx^(xi));
    omegawC= (omegaC + xi - 1.0)/(1.0-alpha);
    omegawX= (omegaX + xi - 1.0)/(1.0-alpha);


    %%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Initialize matrices %%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%
    A_0=zeros(nvar,nvar);
    B_0=zeros(nvar,nvar);
    C_0=zeros(nvar,nvar);
    F_0=zeros(nvar,nz);
    G_0=zeros(nvar,nz);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Construct the matrices %%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
    % EuLER EQUATION FOR DURABLE GOODS
    A_0(1,ipc) = -beta*(1.0-delta);
    A_0(1,ipx) =  beta*(1.0-delta);
    A_0(1,ic)  =  beta*(1.0-delta)*ucc;
    A_0(1,id)  =  beta*(1.0-delta)*ucd;
    B_0(1,ipc) =  1.0;
    B_0(1,ipx) = -1.0;
    B_0(1,ic)  = -(ucc-(1.0-beta*(1.0-delta))*udc);
    B_0(1,id)  = -(ucd-(1.0-beta*(1.0-delta))*udd);
    
    % DEFINITION OF p
    B_0(2,ip)  = 1.0;
    B_0(2,ipc) = -kappaC;
    B_0(2,ipx) = -kappaX;
    
    % DEFINITION OF pc
    B_0(3,iqc) = -(1.0-thetaC);
    B_0(3,ipc) =  1.0;
    C_0(3,ipc) = -thetaC;
    
    % DEFINITION OF px
    B_0(4,ipx) =  1.0;
    B_0(4,iqx) = -(1.0-thetaX);
    C_0(4,ipx) = -thetaX;
    
    % DEFINITION OF qc
    B_0(5,iqc)   =  1.0;
    B_0(5,ipcst) = -(1.0-phiC);
    
    % DEFINITION OF qx
    B_0(6,iqx)   =  1.0;
    B_0(6,ipxst) = -(1.0-phiX);
    
    % pstarc (OPTIMAL PRICING EQUATION IN ND SECTOR)
    A_0(7,ipcst) =  thetaC*beta;
    B_0(7,ipcst) = -1.0;
    B_0(7,imcc)  =  (1.0-thetaC*beta);
    
    % pstarx (OPTIMAL PRICING EQUATION IN D SECTOR)
    A_0(8,ipxst) =  thetaX*beta;
    B_0(8,ipxst) = -1.0;
    B_0(8,imcx)  =  (1.0-thetaX*beta);
    
    % MC OF NONDURABLE GOODS
    B_0(9, imcc) = -1.0;
    B_0(9, ic)   = (omegawC+omegap-ucc)/(1.0+epsilon*omegap);
    B_0(9, ix)   = omegawX/(1.0-alpha)/(1.0+epsilon*omegap);
    B_0(9, id)   = -ucd/(1.0+epsilon*omegap);
    B_0(9, ipc)  = 1.0;

    % MC OF DURABLE GOODS
    B_0(10, imcx) = -1.0;
    B_0(10, ic)   = (omegaC/(1.0-alpha)-ucc)/(1.0+epsilon*omegap);
    B_0(10, ix)   = (omegawX+omegap)/(1.0+epsilon*omegap);
    B_0(10, id)   = -ucd/(1.0+epsilon*omegap);
    B_0(10, ipc)  = 1.0/(1.0+epsilon*omegap);
    B_0(10, ipx)  = epsilon*omegap/(1.0+epsilon*omegap);
   
    % CAPITAL FOR NONDURABLE GOODS
    B_0(11, ikc)  = 1.0;

    % CAPITAL FOR DURABLE GOODS
    B_0(12, ikx)  = 1.0;

    % QUANTITY EQUATION
    B_0(13,ip) = 1.0;
    B_0(13,iy) = 1.0;
    G_0(13,2)  = -1.0;
   
    % DEFINITION OF y
    B_0(14,iy) = -1.0;
    B_0(14,ic) =  kappaC;
    B_0(14,ix) =  kappaX;
    
    % LoM FOR d:
    B_0(15,ix) =  delta;
    B_0(15,id) = -1.0;
    C_0(15,id) =  1.0-delta;
    
    % EXOGENOUS SHOCK PROCESS
    N = [    0,      1;
           -rhoM, 1+rhoM];

    Omega= [0 0;
            0 1];

    

    %------------------------------------%
    % MATRICES WITH LAGGED EXPECTATIONS  %
    %------------------------------------%
    % NAME OF THE COUNTER USED IN B_j
    it_name='J_1';
    % TRUNCATION POINT
    it_max_value=70;
    
    A_j='[zeros(nvar,nvar)]';
    B_j=['[zeros(nvar,nvar)]'...
        '+(J_1>=1)*[zeros(4,nvar);'...
        'zeros(1,ipcst-1) -(1-phiC)*phiC^(J_1) zeros(1,nvar-ipcst);'...
        'zeros(1,ipxst-1) -(1-phiX)*phiX^(J_1) zeros(1,nvar-ipxst);'...
        'zeros(9,nvar)]'];
    C_j='[zeros(nvar,nvar)]';
    F_j='[zeros(nvar,nz)]';
    G_j='[zeros(nvar,nz)]';
    
    %OPTIONS FOR LINLAGEX
    PERIOD=4;

    RUN_IMPULSE=0;
    RUN_ANTICIPATED_IMPULSE=0;
    RUN_SPECTRAL=0;
    RUN_SIMULATION=0;
    solution_method = 'AIM';

    linlagex;

    temp = MA_VECTOR(:,2);
    imp=reshape(temp,[nvar size(temp,1)/nvar])';

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Store the impulse responses %%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % y(t)=[pc(t-1),px(t-1),d(t-1),p(t), pc(t), px(t),qc(t),qx(t),
    %       pc*(t),px*(t),mcc(t),mcx(t),y(t), c(t),x(t), d(t), Kc(t), Kx(t)]
    p(:,idx)   = imp(1:impT,ip);
    pi(:,idx)  = imp(1:impT,ip)-[0;imp(1:impT-1,ip)];
    pc(:,idx)  = imp(1:impT,ipc);
    pic(:,idx) = imp(1:impT,ipc)-[0;imp(1:impT-1,ipc)];
    px(:,idx)  = imp(1:impT,ipx);
    pix(:,idx) = imp(1:impT,ipx)-[0;imp(1:impT-1,ipx)];
    y(:,idx)   = imp(1:impT,iy);
    c(:,idx)   = imp(1:impT,ic);
    x(:,idx)   = imp(1:impT,ix);
    
end

