function [cilasy,ciuasy,varz]=mkinfci(cimat,index,pctg,ndraws,nstep,imp_inf)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Title: mkinfci.m                                                                %
% Usage: This routine computes the confidence interval for inflation series       %
% Input: cimat   = a matrix containing Monte Carlo simulated confidence intervals %
%        index   = the location (column) of a specific price series in cimat      %
%        pctg    = alpha/2, where 1-alpha is the size of a confidence interval    %
%        ndraws  = # of repetition in Monte Carlo simulation                      %
%        nstep   = # of observations for each Monte Carlo simulation              %
%        imp_inf = the impulse response of an inflation series around which       %
%                  confidence interval is created                                 %
% Output:                                                                         % 
%         cilasy = the lower bound of MC simulated inflation impulse              %
%                  response using normal approximation                            %
%         ciuasy = the upper bound of MC simulated inflation impulse              %
%                  response using normal approximation                            %
%         varz   = variance of each variable                                      %
% Author: T. Takamura                                                             %
% Date: February 2009                                                             %
% Note: This routine supplements the SVAR codes written by Vigfusson              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % Pick up a specific price IR indexed by 'index' and take a difference
    % to convert it to inflation.  Append zeros for the initial period.
    ci_inf=cimat(2:end,index,:)-cimat(1:end-1,index,:);
    ci_inf=[zeros(1,1,ndraws);ci_inf];
    
    % Asymptotic normal approximation
    if nargin==6
        for i=1:nstep
            ci_inf(i,:,:) = ci_inf(i,:,:)-mean(ci_inf(i,:,:),3);
        end
        
        varz = (1/ndraws)*sum(ci_inf(:,:,:).^2,3);
        
        ciuasy = imp_inf + norminv(1-pctg,0,1)*sqrt(varz);
        cilasy = imp_inf - norminv(1-pctg,0,1)*sqrt(varz);
    end
