%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%     MATLAB CODE FOR REPRODUCING FIGURES 2, 3 AND 4 IN THE MAIN TEXT 
%%%     WRITTEN BY TAMON TAKAMURA
%%%     
%%%     JANUARY 2021
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear
clc
tic

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Set parameter values %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure_num = 2;       % 2 FOR FIGURE 2; 3 FOR FIGURE 3; 4 FOR Figure 4
sub_label  = 1;       % FOR FIGURES 3-4 ONLY: 1 FOR PANEL (a) AND 2 FOR PANEL (b)       

beta    = 0.98^0.25;  % SUBJECTIVE DISCOUNT FACTOR
alpha   = 0.35;       % CAPITAL SHARE
delta   = 0.05/4;     % DEPRECIATION RATE OF DURABLE GOODS
eta     = 1.0;        % FRISCH ELASTICITY OF LABOR SUPPLY
epsilon = 11.0;       % ELASTICITY OF DEMAND
theta   = 0.5;        % STICKY PRICE PARAMETER (CALVO PROBABILITY) 
impT    = 26;         % NUMBER OF PERIODS TO CALCULATE THE IMPULSE RESPONSES

% PARAMETER VALUES TO SIMULATE
if (figure_num==2)
    
    fsp_l = 0;
    fsp_k = 0;
    
    % order: [kappaC,    phiC,   phiX,   thetaC, thetaX, sigma, rho,  delta,    eta, alpha, beta, epsilon]
    paramvec=[  0.75,    0.0,    0.0,    0.75,   0.2,    1.0,   1.0,  delta,    eta, alpha, beta, epsilon; 
                0.75,    0.0,    0.0,    0.6,    0.3,    1.0,   1.0,  delta,    eta, alpha, beta, epsilon;  
                0.75,    0.0,    0.0,    0.3,    0.6,    1.0,   1.0,  delta,    eta, alpha, beta, epsilon; 
                0.75,    0.0,    0.0,    0.2,    0.75,   1.0,   1.0,  delta,    eta, alpha, beta, epsilon]; 
   
elseif (figure_num==3)
    
    if (sub_label==1)
    
        fsp_l = 2;
        fsp_k = 2;

        % order: [kappaC,    phiC,   phiX,   thetaC, thetaX, sigma, rho,  delta,    eta, alpha, beta, epsilon]
        paramvec=[  0.75,    0.0,    0.0,    theta,  0.0,   1.0,   1.0,  delta,    eta, alpha, beta, epsilon;
                    0.75,    0.25,   0.25,   theta,  0.0,   1.0,   1.0,  delta,    eta, alpha, beta, epsilon;  
                    0.75,    0.5,    0.5,    theta,  0.0,   1.0,   1.0,  delta,    eta, alpha, beta, epsilon; 
                    0.75,    0.75,   0.75,   theta,  0.0,   1.0,   1.0,  delta,    eta, alpha, beta, epsilon];   
                    
    elseif (sub_label==2)

        fsp_l = 0;
        fsp_k = 0;

        % order: [kappaC,    phiC,   phiX,   thetaC, thetaX, sigma, rho,  delta,    eta, alpha, beta, epsilon]
        paramvec=[  0.75,    0.0,    0.0,    theta,  0.0,   1.0,   1.0,  delta,    eta, alpha, beta, epsilon;
                    0.75,    0.25,   0.25,   theta,  0.0,   1.0,   1.0,  delta,    eta, alpha, beta, epsilon;  
                    0.75,    0.5,    0.5,    theta,  0.0,   1.0,   1.0,  delta,    eta, alpha, beta, epsilon; 
                    0.75,    0.75,   0.75,   theta,  0.0,   1.0,   1.0,  delta,    eta, alpha, beta, epsilon];  
                
    end

elseif (figure_num==4)
    
    if (sub_label==1)
        
        fsp_l = 0;
        fsp_k = 0;
        
        paramvec=[  0.75,    0.00,     0.325,    0.5,   0.0,    1.0,   1.0,  delta,    eta, alpha, beta, epsilon; 
                    0.75,    0.00,     0.0,      0.5,   0.325,  1.0,   1.0,  delta,    eta, alpha, beta, epsilon];  
    
    elseif (sub_label==2)
        
        fsp_l = 2;
        fsp_k = 2;
    
        paramvec=[  0.75,    0.00,     0.325,  0.5,   0.0,    1.0,   1.0,  delta,    eta, alpha, beta, epsilon; 
                    0.75,    0.00,     0.0,    0.5,   0.325,  1.0,   1.0,  delta,    eta, alpha, beta, epsilon];  
        
    end
    
end

[p, pi, pc, pic, px, pix, y, c, x] = dual_stickiness_bhk(paramvec, fsp_l, fsp_k, impT);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  Plot the impulse response functions %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

lw = 2;
set(0,'DefaultLineLineWidth',lw)
set(0,'DefaultAxesFontSize',20,'DefaultAxesFontName','Arial')
set(0,'DefaultTextFontSize',20,'DefaultTextFontName','Arial')
ltypes = char('r--','k:','b-*','b-'); 

figure('units','normalized','outerposition',[0 0 1 1])
orient portrait
set(gcf,'renderer','Painters')
set(gcf, 'Color', 'w');

if (figure_num==2)

    subplot(1,3,1)
    for idx=1:size(paramvec,1)
        if (idx~=3)
            plot((0:(impT-1)), c(:,idx), deblank(ltypes(idx,:)))
        else
            plot((0:(impT-1)), c(:,idx), deblank(ltypes(idx,:)),'Color', [0.4 0.4 0.4],'LineWidth',lw*2)
        end
        hold on
    end
    if (fsp_l==0 && fsp_k==0)

        xlim([0 15])
        txt1=['$\theta_{c}=', num2str(paramvec(1,4)), ', \theta_{x}=', num2str(paramvec(1,5)),'$'];
        txt2=['$\theta_{c}=', num2str(paramvec(2,4)), ',\  \ \theta_{x}=', num2str(paramvec(2,5)),'$'];
        txt3=['$\theta_{c}=', num2str(paramvec(3,4)), ', \ \ \theta_{x}=', num2str(paramvec(3,5)),'$'];
        txt4=['$\theta_{c}=', num2str(paramvec(4,4)), ', \ \ \theta_{x}=', num2str(paramvec(4,5)),'$'];
        h=legend(txt1,txt2, txt3,txt4,'Location', 'NorthEast','Interpreter','Latex');
        set(h,'FontSize',10)

    else
        xlim([0 15])
    end
    title('Nondurable Production','fontsize',16,'Interpreter','Latex')

    subplot(1,3,2)
    for idx=1:size(paramvec,1)
        if (idx~=3)
            plot((0:(impT-1)), x(:,idx), deblank(ltypes(idx,:)))
        else
            plot((0:(impT-1)), x(:,idx), deblank(ltypes(idx,:)),'Color', [0.4 0.4 0.4],'LineWidth',lw*2)
        end
        hold on
    end
    xlim([0 15])
    title('Durable Production','fontsize',16,'Interpreter','Latex')

    subplot(1,3,3)
    for idx=1:size(paramvec,1)
        if (idx~=3)
            plot((0:(impT-1)), px(:,idx)-pc(:,idx), deblank(ltypes(idx,:)))
        else
            plot((0:(impT-1)), px(:,idx)-pc(:,idx), deblank(ltypes(idx,:)),'Color', [0.4 0.4 0.4],'LineWidth',lw*2)
        end
        hold on
    end
    xlim([0 15])
    title('Relative Price','fontsize',16,'Interpreter','Latex')

elseif (figure_num==3)
    
    subplot(2,3,1)
    for idx=1:size(paramvec,1)
        if (idx~=3)
            plot((0:(impT-1)), c(:,idx), deblank(ltypes(idx,:)))
        else
            plot((0:(impT-1)), c(:,idx), deblank(ltypes(idx,:)),'Color', [0.4 0.4 0.4],'LineWidth',3)
        end
        hold on
    end
    xlim([0 15])
    if (sub_label==1)
        ylim([0 1.0])
    elseif (sub_label==2)
        ylim([0 0.7])
    end
    title('Nondurable Production','fontsize',16,'Interpreter','Latex')

    subplot(2,3,2)
    for idx=1:size(paramvec,1)
        if (idx~=3)
            plot((0:(impT-1)), x(:,idx), deblank(ltypes(idx,:)))
        else
            plot((0:(impT-1)), x(:,idx), deblank(ltypes(idx,:)),'Color', [0.4 0.4 0.4],'LineWidth',3)
        end
        hold on
    end
    xlim([0 15])
    if (sub_label==1)
        ylim([-1.0 5.0])
    elseif (sub_label==2)
        ylim([-2.0 3.0])
    end
    title('Durable Production','fontsize',16,'Interpreter','Latex')

    subplot(2,3,3)
    for idx=1:size(paramvec,1)
        if (idx~=3)
            plot((0:(impT-1)), px(:,idx)-pc(:,idx), deblank(ltypes(idx,:)))
        else
            plot((0:(impT-1)), px(:,idx)-pc(:,idx), deblank(ltypes(idx,:)),'Color', [0.4 0.4 0.4],'LineWidth',3)
        end
        hold on
    end
    xlim([0 15])
    if (sub_label==1)
        ylim([0 1.0])
    elseif (sub_label==2)
        ylim([0 0.8])
    end
    title('Relative Price','fontsize',16,'Interpreter','Latex')

    subplot(2,3,4)
    for idx=1:size(paramvec,1)
        if (idx~=3)
            plot((0:(impT-1)), pic(:,idx), deblank(ltypes(idx,:)))
        else
            plot((0:(impT-1)), pic(:,idx), deblank(ltypes(idx,:)),'Color', [0.4 0.4 0.4],'LineWidth',3)
        end
        hold on
    end
    xlim([0 15])
    if (sub_label==1)
        ylim([0 0.5])
    elseif (sub_label==2)
        ylim([0 1.0])
    end
    title('Nondurable Inflation','fontsize',16,'Interpreter','Latex')

    subplot(2,3,5)
    for idx=1:size(paramvec,1)
        if (idx~=3)
            plot((0:(impT-1)), pix(:,idx), deblank(ltypes(idx,:)))
        else
            plot((0:(impT-1)), pix(:,idx), deblank(ltypes(idx,:)),'Color', [0.4 0.4 0.4],'LineWidth',3)
        end
        hold on
    end
    xlim([0 15])
    if (sub_label==1)
        ylim([0 1.2])
    elseif (sub_label==2)
        ylim([0 1.5])
    end
    title('Durable Inflation','fontsize',16,'Interpreter','Latex')

    hSub = subplot(2,3,6); 
    for idx=1:size(paramvec,1)
        if (idx~=3)
            plot(1, nan, deblank(ltypes(idx,:))) 
        else
            plot(1, nan, deblank(ltypes(idx,:)),'Color', [0.4 0.4 0.4],'LineWidth',3) 
        end
        hold on
    end 
    set(hSub, 'Visible', 'off');
    legend_s1 = ['$ \phi_{c} = \phi_{x} = ',num2str(paramvec(1,2)), '$'];
    legend_s2 = ['$ \phi_{c} = \phi_{x} = ',num2str(paramvec(2,2)), '$'];
    legend_s3 = ['$ \phi_{c} = \phi_{x} = ',num2str(paramvec(3,2)), '$'];
    legend_s4 = ['$ \phi_{c} = \phi_{x} = ',num2str(paramvec(4,2)), '$'];
    legend(legend_s1, legend_s2, legend_s3, legend_s4, 'Interpreter','Latex', 'Fontsize',18,'Location','NorthEast');

elseif (figure_num==4)
    
    subplot(2,2,1)
    xax = (0:(impT-1))';
    plot(xax, c(:,1), 'b-', xax, c(:,2), 'r--')
    title('Nondurable Production','fontsize',24,'Interpreter','Latex')
    legend_s1 = 'Sticky information in durable goods';
    legend_s2 = 'Sticky prices in durable goods';
    legend(legend_s1, legend_s2,'fontsize',10, 'Interpreter','Latex')

    subplot(2,2,2)
    plot(xax, x(:,1), 'b-', xax, x(:,2), 'r--', xax, zeros(impT,1),'k:')
    title('Durable Production','fontsize',24,'Interpreter','Latex')

    subplot(2,2,3)
    plot(xax, pic(:,1), 'b-', xax, pic(:,2), 'r--')
    title('Nondurable Inflation','fontsize',24,'Interpreter','Latex')

    subplot(2,2,4)
    plot(xax, pix(:,1), 'b-', xax, pix(:,2), 'r--')
    title('Durable Inflation','fontsize',24,'Interpreter','Latex')
    
end


toc
