clear
clc

% PRE-COMPUTED IRFs OF THE MODEL WITH STICKY PRICES ONLY
load ResultKnitro_ir_noSI.mat
c_sp    = IRFmodel(:,1);
x_sp    = IRFmodel(:,2);
pic_sp  = IRFmodel(:,3);
pix_sp  = IRFmodel(:,4);

clearvars -except c_sp x_sp pic_sp pix_sp

% PRE-COMPUTED IRFs OF THE MODEL WITH DUAL STICKINESS 
load ResultKnitro_ir.mat
c_tr    = IRFmodel(:,1);
x_tr    = IRFmodel(:,2);
pic_tr  = IRFmodel(:,3);
pix_tr  = IRFmodel(:,4);

% TITLE FONTSIZE
tfs = 16;

% PERIODS
tend = 25;
tt = 0:1:24;

%% TURN OFF HABIT FORMATION
xpara_noHb        = xpara_mde;
xpara_noHb.varrho = 0.0;

IRF_noHb = CompIRF_ir(xpara_noHb,1:tend);
IRF_noHb = reshape(IRF_noHb, tend, 4);
c_noHb   = IRF_noHb(1:tend,1);
x_noHb   = IRF_noHb(1:tend,2);
pic_noHb = IRF_noHb(1:tend,3);
pix_noHb = IRF_noHb(1:tend,4);

%% TURN OFF RESIDENTIAL INVESTMENT ADJUSTMENT COST
xpara_noAd        = xpara_mde;
xpara_noAd.xi     = 0.0;

IRF_noAd = CompIRF_ir(xpara_noAd,1:tend);
IRF_noAd = reshape(IRF_noAd, tend, 4);
c_noAd   = IRF_noAd(1:tend,1);
x_noAd   = IRF_noAd(1:tend,2);
pic_noAd = IRF_noAd(1:tend,3);
pix_noAd = IRF_noAd(1:tend,4);

%% PLOT FIGURES A2 

lw = 2;
set(0,'DefaultLineLineWidth',lw);
set(0,'DefaultAxesFontSize',20,'DefaultAxesFontName','Arial');
set(0,'DefaultTextFontSize',20,'DefaultTextFontName','Arial');

figure('units','normalized','outerposition',[0 0 1 1])
orient portrait
set(gcf,'renderer','Painters')
set(gcf, 'Color', 'w');

subplot(2,2,1);
plot(tt,IRFc,'r--')
hold on
plot(tt, c_tr(1:tend), 'b-', 'LineWidth', lw*2)
hold on
plot(tt, c_sp(1:tend),'-*', 'Color',[0.4 0.4 0.4], 'LineWidth', lw)
hold on
plot(tt,UCI(1:tend,1),'r:',tt,LCI(1:tend,1),'r:') 
hold on
plot(tt, zeros(tend,1),'k-','LineWidth',1);
hold off
title('Nondurable Goods \& Services', 'fontsize', tfs, 'Interpreter','Latex');
ylabel('percentage','fontsize',12);
xlim([0 tend-1]);

subplot(2,2,2);
plot(tt,IRFx,'r--')
hold on
plot(tt,x_tr(1:tend),'b-', 'LineWidth', lw*2)
hold on
plot(tt, x_sp(1:tend),'-*','Color',[0.4 0.4 0.4], 'LineWidth', lw)
hold on
plot(tt,UCI(1:tend,2),'r:',tt,LCI(1:tend,2),'r:')
hold on
plot(tt, zeros(tend,1),'k-','LineWidth',1);
hold off
title('Residential Investment', 'fontsize', tfs, 'Interpreter','Latex');
ylabel('percentage','fontsize',12);
legend('VAR','Model','sticky prices only','Location','NorthEast','Interpreter','Latex','fontsize',15);
legend boxoff
xlim([0 tend-1]);

subplot(2,2,3);
plot(tt,IRFpic,'r--')
hold on
plot(tt,pic_tr(1:tend),'b-', 'LineWidth',2*lw)
hold on
plot(tt,pic_sp(1:tend),'-*','Color',[0.4 0.4 0.4], 'LineWidth', lw)
hold on
plot(tt,UCI(1:tend,3),'r:',tt,LCI(1:tend,3),'r:')
hold on
plot(tt, zeros(tend,1),'k-','LineWidth',1);
hold off
title('Inflation of Nondurable Goods \& Services', 'fontsize', tfs, 'Interpreter','Latex')
ylabel('percentage point','fontsize',12);
xlim([0 tend-1]);

subplot(2,2,4);
plot(tt,IRFpix,'r--')
hold on
plot(tt,pix_tr(1:tend),'b-', 'LineWidth', 2*lw)
hold on
plot(tt,pix_sp(1:tend),'-*','Color',[0.4 0.4 0.4], 'LineWidth', lw)
hold on
plot(tt,UCI(1:tend,4),'r:',tt,LCI(1:tend,4),'r:')
hold on
plot(tt, zeros(tend,1),'k-','LineWidth',1);
hold off
title('Residential Price Inflation', 'fontsize', tfs, 'Interpreter','Latex');
ylabel('percentage point','fontsize',12);
xlim([0 tend-1]);


%% PLOT FIGURES A3 

figure('units','normalized','outerposition',[0 0 1 1])
orient portrait
set(gcf,'renderer','Painters')
set(gcf, 'Color', 'w');

subplot(2,2,1);
plot(tt,IRFc,'r--')
hold on
plot(tt,c_noHb(1:tend),'c*--','LineWidth',lw)
hold on
plot(tt,c_noAd(1:tend),'md-','LineWidth',lw)
hold on
plot(tt,UCI(1:tend,1),'r:',tt,LCI(1:tend,1),'r:') 
hold on
plot(tt, zeros(tend,1),'k-','LineWidth',1);
hold off
title('Nondurable Goods \& Services', 'fontsize', tfs, 'Interpreter','Latex');
ylabel('percentage','fontsize',12);
xlim([0 tend-1]);

subplot(2,2,2);
plot(tt,IRFx,'r--')
hold on
plot(tt, x_noHb(1:tend),'c*--', 'LineWidth', lw)
hold on
plot(tt,x_noAd(1:tend),'md-','LineWidth',lw)
hold on
plot(tt,UCI(1:tend,2),'r:',tt,LCI(1:tend,2),'r:')
hold on
plot(tt, zeros(tend,1),'k-','LineWidth',1);
hold off
title('Residential Investment', 'fontsize', tfs, 'Interpreter','Latex');
ylabel('percentage','fontsize',12);
legend('VAR','no habit formation','no investment adjustment cost','Location','NorthEast', 'Interpreter','Latex','Interpreter','Latex','fontsize',14);
legend boxoff
xlim([0 tend-1]);

subplot(2,2,3);
plot(tt,IRFpic,'r--')
hold on
plot(tt,pic_noHb(1:tend),'c*--', 'LineWidth', 3)
hold on
plot(tt,pic_noAd(1:tend),'md-','LineWidth',lw)
hold on
plot(tt,UCI(1:tend,3),'r:',tt,LCI(1:tend,3),'r:')
hold on
plot(tt, zeros(tend,1),'k-','LineWidth',1);
hold off
title('Inflation of Nondurable Goods \& Services', 'fontsize', tfs, 'Interpreter','Latex')
ylabel('percentage point','fontsize',12);
xlim([0 tend-1]);

subplot(2,2,4);
plot(tt,IRFpix,'r--')
hold on
plot(tt,pix_noHb(1:tend),'c*--', 'LineWidth', lw)
hold on
plot(tt,pix_noAd(1:tend),'md-','LineWidth',lw)
hold on
plot(tt,UCI(1:tend,4),'r:',tt,LCI(1:tend,4),'r:')
hold on
plot(tt, zeros(tend,1),'k-','LineWidth',1);
hold off
title('Residential Price Inflation', 'fontsize', tfs, 'Interpreter','Latex');
ylabel('percentage point','fontsize',12);
xlim([0 tend-1]);


